Genshi
======

The package provides an implementation of the Genshi
language. However, unlike the reference implementation which comes
with a complete ecosystem of supporting components, this
implementation is rather bare-bones.

.. note:: Support for match templates (experimental) requires ``lxml``.

Reference
---------

Please see the Genshi `XML template reference <http://genshi.edgewall.org/wiki/Documentation/0.5.x/templates.html>`_.

For internationalization support, see :ref:`i18n_chapter`.

.. _genshitemplate_api_module:

API reference
-------------

This section contains an autogenerated API reference.

The ``GenshiTemplate*`` constructors create templates from XML files.

.. automodule:: chameleon.genshi.template

  .. autoclass:: chameleon.genshi.template.GenshiTemplate

  .. autoclass:: chameleon.genshi.template.GenshiTemplateFile

  .. autoclass:: chameleon.genshi.template.GenshiTextTemplate

  .. autoclass:: chameleon.genshi.template.GenshiTextTemplateFile

A template loader class is provided (for use with Pylons and other
platforms).

.. automodule:: chameleon.genshi.loader

  .. autoclass:: chameleon.genshi.loader.TemplateLoader
